@@ -1,7 +1,7 @@
 from ...util import registry
 
 
-@registry.keyboards("hu_qwerty.v1")
+@registry.keyboards("hu_qwerty_v1")
 def create_qwerty_hu():
     qwerty = {
         "default": [
